/*
 * Copyright 2008-2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.ant.internal.support;

import java.util.List;
import java.util.Properties;

import org.apache.tools.ant.types.PropertySet;

import com.springsource.bundlor.support.properties.PropertiesSource;

/**
 * {@link PropertiesSource} implementation that wraps a list of {@link PropertySet}s and exposes a
 * {@link Properties} view to the {@link PropertySet}s name-value pairs.
 * 
 * @author Christian Dupuis
 */
final class PropertySetPropertiesSource implements PropertiesSource {
	
	/** Eagerly created {@link Properties} instance containing all resolved name-value pairs */
	private final Properties properties;
	
	/**
	 * Create a new {@link PropertySetPropertiesSource} with the given <code>propertySets</code>.
	 * 
	 * @param propertySets list of {@link PropertySet}s
	 */
	public PropertySetPropertiesSource(List<PropertySet> propertySets) {
		this.properties = new Properties();
		for (PropertySet propertySet : propertySets) {
			this.properties.putAll(propertySet.getProperties());
		}
	}
	
	/**
	 * {@inheritDoc}
	 */
	public int getPriority() {
		return Integer.MAX_VALUE;
	}

	/**
	 * {@inheritDoc}
	 */
	public Properties getProperties() {
		return properties;
	}

}
