/*
 * Copyright 2008-2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.support.contributors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Set;

import org.junit.Test;

import com.springsource.bundlor.support.partialmanifest.ReadablePartialManifest;
import com.springsource.bundlor.support.partialmanifest.StandardReadablePartialManifest;

public class HibernateMappingArtefactAnalyserTests {

    private static final String artifactName = "src/test/resources/com/springsource/bundlor/support/contributors/hibernate.hbm";

    private final HibernateMappingArtefactAnalyser analyzer = new HibernateMappingArtefactAnalyser();

    @Test
    public void testCanAnalyze() {
        assertTrue(analyzer.canAnalyse(artifactName));
        assertFalse(analyzer.canAnalyse(artifactName + "1"));
    }

    @Test
    public void testAnalyze() throws Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        InputStream artifact = new FileInputStream(artifactName);

        analyzer.analyse(artifact, artifactName, partialManifest);
        Set<String> imports = partialManifest.getImportedPackages();

        assertEquals(17, imports.size());
    }
}
